@@ -32,7 +32,6 @@ class DatabaseCreation(NonrelDatabaseCreation):
         'XMLField':          'text',
         'GenericAutoField':  'id',
         'StringForeignKey':  'id',
-        'AutoField':         'id',
         'RelatedAutoField':  'id',
     }
 
@@ -77,7 +76,8 @@ class DatabaseCreation(NonrelDatabaseCreation):
             verbosity=max(verbosity - 1, 0),
             interactive=False,
             database=self.connection.alias,
-            load_initial_data=False)
+            load_initial_data=False
+        )
 
         return test_database_name
 
